@@ -47,20 +47,20 @@
 *     Research Councils
 
 *  Licence:
-*     This program is free software; you can redistribute it and/or
-*     modify it under the terms of the GNU General Public Licence as
-*     published by the Free Software Foundation; either version 2 of
-*     the Licence, or (at your option) any later version.
+*     This program is free software: you can redistribute it and/or
+*     modify it under the terms of the GNU Lesser General Public
+*     License as published by the Free Software Foundation, either
+*     version 3 of the License, or (at your option) any later
+*     version.
 *
-*     This program is distributed in the hope that it will be
-*     useful,but WITHOUT ANY WARRANTY; without even the implied
-*     warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-*     PURPOSE. See the GNU General Public Licence for more details.
+*     This program is distributed in the hope that it will be useful,
+*     but WITHOUT ANY WARRANTY; without even the implied warranty of
+*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+*     GNU Lesser General Public License for more details.
 *
-*     You should have received a copy of the GNU General Public Licence
-*     along with this program; if not, write to the Free Software
-*     Foundation, Inc., 51 Franklin Street,Fifth Floor, Boston, MA
-*     02110-1301, USA
+*     You should have received a copy of the GNU Lesser General
+*     License along with this program.  If not, see
+*     <http://www.gnu.org/licenses/>.
 
 *  Authors:
 *     RFWS: R.F. Warren-Smith (Starlink)
@@ -189,6 +189,7 @@ typedef struct AstSkyFrame {
    char *projection;             /* Description of sky projection */
    double equinox;               /* Modified Julian Date of mean equinox */
    int neglon;                   /* Display negative longitude values? */
+   double skytol;                /* Smallest significant distance */
    int alignoffset;              /* Align SkyFrame in offset coords? */
    int skyrefis;                 /* Nature of offset coord system */
    double skyref[ 2 ];           /* Origin or pole of offset coord system */
@@ -240,6 +241,11 @@ typedef struct AstSkyFrameVtab {
    void (* ClearSkyRefIs)( AstSkyFrame *, int * );
    void (* SetSkyRefIs)( AstSkyFrame *, int, int * );
 
+   double (* GetSkyTol)( AstSkyFrame *, int * );
+   int (* TestSkyTol)( AstSkyFrame *, int * );
+   void (* ClearSkyTol)( AstSkyFrame *, int * );
+   void (* SetSkyTol)( AstSkyFrame *, double, int * );
+
    double (* GetSkyRef)( AstSkyFrame *, int, int * );
    int (* TestSkyRef)( AstSkyFrame *, int, int * );
    void (* ClearSkyRef)( AstSkyFrame *, int, int * );
@@ -363,6 +369,10 @@ int astTestSkyRefP_( AstSkyFrame *, int, int * );
 void astClearSkyRefP_( AstSkyFrame *, int, int * );
 void astSetSkyRefP_( AstSkyFrame *, int, double, int * );
 
+double astGetSkyTol_( AstSkyFrame *, int * );
+int astTestSkyTol_( AstSkyFrame *, int * );
+void astClearSkyTol_( AstSkyFrame *, int * );
+void astSetSkyTol_( AstSkyFrame *, double, int * );
 
 #endif
 
@@ -481,6 +491,11 @@ astINVOKE(V,astTestProjection_(astCheckSkyFrame(this),STATUS_PTR))
 #define astSetSkyRefP(this,axis,value) astINVOKE(V,astSetSkyRefP_(astCheckSkyFrame(this),axis,value,STATUS_PTR))
 #define astTestSkyRefP(this,axis) astINVOKE(V,astTestSkyRefP_(astCheckSkyFrame(this),axis,STATUS_PTR))
 
+#define astClearSkyTol(this) astINVOKE(V,astClearSkyTol_(astCheckSkyFrame(this),STATUS_PTR))
+#define astGetSkyTol(this) astINVOKE(V,astGetSkyTol_(astCheckSkyFrame(this),STATUS_PTR))
+#define astSetSkyTol(this,value) astINVOKE(V,astSetSkyTol_(astCheckSkyFrame(this),value,STATUS_PTR))
+#define astTestSkyTol(this) astINVOKE(V,astTestSkyTol_(astCheckSkyFrame(this),STATUS_PTR))
+
 #endif
 #endif
 
